<?php
/*
Plugin Name: Order Statistics (EasyToolsWP)
Description: Plugin to display average order price, order count, items per order, and comparisons with percentage changes to previous periods in a compact layout.
Version: 1.9
Author: EasyToolsWP.com
*/

// Hook to admin dashboard
add_action('wp_dashboard_setup', 'custom_woocommerce_dashboard_widgets');

function custom_woocommerce_dashboard_widgets() {
    wp_add_dashboard_widget('custom_woocommerce_order_stats', 'WooCommerce Order Statistics', 'woocommerce_order_stats_display');
}

function woocommerce_order_stats_display() {
    // Get today's data
    $orders_today = get_orders_today();
    $avg_order_today = calculate_avg_order($orders_today);
    $order_count_today = count($orders_today);
    $items_per_order_today = calculate_items_per_order($orders_today);

    // Get yesterday's data
    $orders_yesterday = get_orders_for_day(date('Y-m-d', strtotime('-1 day')));
    $avg_order_yesterday = calculate_avg_order($orders_yesterday);
    $order_count_yesterday = count($orders_yesterday);
    $items_per_order_yesterday = calculate_items_per_order($orders_yesterday);

    // Get weekly data
    $orders_this_week = get_orders_for_week(date('W'));
    $avg_order_this_week = calculate_avg_order($orders_this_week);
    $order_count_this_week = count($orders_this_week);
    $items_per_order_this_week = calculate_items_per_order($orders_this_week);

    $orders_last_week = get_orders_for_week(date('W') - 1);
    $avg_order_last_week = calculate_avg_order($orders_last_week);
    $order_count_last_week = count($orders_last_week);
    $items_per_order_last_week = calculate_items_per_order($orders_last_week);

    // Get last year same week
    $orders_last_year_same_week = get_orders_for_week(date('W'), date('Y') - 1);
    $avg_order_last_year_same_week = calculate_avg_order($orders_last_year_same_week);
    $order_count_last_year_same_week = count($orders_last_year_same_week);
    $items_per_order_last_year_same_week = calculate_items_per_order($orders_last_year_same_week);

    // Get monthly data
    $orders_this_month = get_orders_for_month(date('m'));
    $avg_order_this_month = calculate_avg_order($orders_this_month);
    $order_count_this_month = count($orders_this_month);
    $items_per_order_this_month = calculate_items_per_order($orders_this_month);

    $orders_last_month = get_orders_for_month(date('m', strtotime('first day of last month')));
    $avg_order_last_month = calculate_avg_order($orders_last_month);
    $order_count_last_month = count($orders_last_month);
    $items_per_order_last_month = calculate_items_per_order($orders_last_month);

    // Get last year same month
    $orders_last_year_same_month = get_orders_for_month(date('m'), date('Y') - 1);
    $avg_order_last_year_same_month = calculate_avg_order($orders_last_year_same_month);
    $order_count_last_year_same_month = count($orders_last_year_same_month);
    $items_per_order_last_year_same_month = calculate_items_per_order($orders_last_year_same_month);

    // Get yearly data
    $orders_this_year = get_orders_for_year(date('Y'));
    $avg_order_this_year = calculate_avg_order($orders_this_year);
    $order_count_this_year = count($orders_this_year);
    $items_per_order_this_year = calculate_items_per_order($orders_this_year);

    $orders_last_year = get_orders_for_year(date('Y') - 1);
    $avg_order_last_year = calculate_avg_order($orders_last_year);
    $order_count_last_year = count($orders_last_year);
    $items_per_order_last_year = calculate_items_per_order($orders_last_year);

    // Enqueue jQuery for toggle functionality
    wp_enqueue_script('jquery');

    // Styling and JavaScript
    echo "<style>
        .order-stats-section { margin-bottom: 20px; }
        .order-stats-header { padding: 10px; background: #f1f1f1; border-radius: 5px; margin-bottom: 10px; font-size: 1.1em; font-weight: bold; cursor: pointer; }
        .order-stats-data { padding: 10px; background: #f9f9f9; border: 1px solid #ddd; border-radius: 5px; display: none; }
        .order-stats-data p { margin: 0; line-height: 1.8em; }
        .order-stats-data strong { font-weight: bold; }
        .percent-up { color: green; font-weight: bold; }
        .percent-down { color: red; font-weight: bold; }
        .small-text { font-size: 0.9em; color: #666; }
    </style>";

    echo "<script>
        jQuery(document).ready(function($) {
            $('.order-stats-header').on('click', function() {
                $(this).next('.order-stats-data').slideToggle();
                // Optionally add code to handle open/close states if needed
            });
            
            // Open the 'Week' tab by default
            $('.order-stats-header:contains(\"Week " . date('W') . "\")').next('.order-stats-data').show();
        });
    </script>";

    // Helper functions for calculating percentage changes and displaying them
    function percentage_change($current, $previous) {
        if ($previous == 0) {
            return $current > 0 ? 100 : 0; // Avoid division by zero
        }
        return (($current - $previous) / $previous) * 100;
    }

    function display_change($current, $previous) {
        $change = percentage_change($current, $previous);
        $change_formatted = number_format($change, 2);
        if ($change > 0) {
            return "<span class='percent-up'>▲ {$change_formatted}%</span>";
        } elseif ($change < 0) {
            return "<span class='percent-down'>▼ {$change_formatted}%</span>";
        } else {
            return "<span>0%</span>";
        }
    }

    // HTML output

    // Today's vs Yesterday's comparison
    echo "<div class='order-stats-section'>
        <div class='order-stats-header'>Today vs Yesterday</div>
        <div class='order-stats-data'>
            <p><strong>Average Order Price:</strong> " . wc_price($avg_order_today) . " (" . wc_price($avg_order_yesterday) . ") " . display_change($avg_order_today, $avg_order_yesterday) . "</p>
            <p class='small-text'>Same Period Last Year: " . wc_price($avg_order_last_year_same_week) . " " . display_change($avg_order_today, $avg_order_last_year_same_week) . "</p>
            <p><strong>Order Count:</strong> " . $order_count_today . " (" . $order_count_yesterday . ") " . display_change($order_count_today, $order_count_yesterday) . "</p>
            <p class='small-text'>Same Period Last Year: " . $order_count_last_year_same_week . " " . display_change($order_count_today, $order_count_last_year_same_week) . "</p>
            <p><strong>Items per Order:</strong> " . number_format($items_per_order_today, 2) . " (" . number_format($items_per_order_yesterday, 2) . ") " . display_change($items_per_order_today, $items_per_order_yesterday) . "</p>
            <p class='small-text'>Same Period Last Year: " . number_format($items_per_order_last_year_same_week, 2) . " " . display_change($items_per_order_today, $items_per_order_last_year_same_week) . "</p>
        </div>
    </div>";

    // Weekly comparison
    echo "<div class='order-stats-section'>
        <div class='order-stats-header'>Week " . date('W') . " vs Last Week</div>
        <div class='order-stats-data'>
            <p><strong>Average Order Price:</strong> " . wc_price($avg_order_this_week) . " (" . wc_price($avg_order_last_week) . ") " . display_change($avg_order_this_week, $avg_order_last_week) . "</p>
            <p class='small-text'>Same Period Last Year: " . wc_price($avg_order_last_year_same_week) . " " . display_change($avg_order_this_week, $avg_order_last_year_same_week) . "</p>
            <p><strong>Order Count:</strong> " . $order_count_this_week . " (" . $order_count_last_week . ") " . display_change($order_count_this_week, $order_count_last_week) . "</p>
            <p class='small-text'>Same Period Last Year: " . $order_count_last_year_same_week . " " . display_change($order_count_this_week, $order_count_last_year_same_week) . "</p>
            <p><strong>Items per Order:</strong> " . number_format($items_per_order_this_week, 2) . " (" . number_format($items_per_order_last_week, 2) . ") " . display_change($items_per_order_this_week, $items_per_order_last_week) . "</p>
            <p class='small-text'>Same Period Last Year: " . number_format($items_per_order_last_year_same_week, 2) . " " . display_change($items_per_order_this_week, $items_per_order_last_year_same_week) . "</p>
        </div>
    </div>";

    // Monthly comparison
    echo "<div class='order-stats-section'>
        <div class='order-stats-header'>Month: " . date('F') . " vs Last Month</div>
        <div class='order-stats-data'>
            <p><strong>Average Order Price:</strong> " . wc_price($avg_order_this_month) . " (" . wc_price($avg_order_last_month) . ") " . display_change($avg_order_this_month, $avg_order_last_month) . "</p>
            <p class='small-text'>Same Period Last Year: " . wc_price($avg_order_last_year_same_month) . " " . display_change($avg_order_this_month, $avg_order_last_year_same_month) . "</p>
            <p><strong>Order Count:</strong> " . $order_count_this_month . " (" . $order_count_last_month . ") " . display_change($order_count_this_month, $order_count_last_month) . "</p>
            <p class='small-text'>Same Period Last Year: " . $order_count_last_year_same_month . " " . display_change($order_count_this_month, $order_count_last_year_same_month) . "</p>
            <p><strong>Items per Order:</strong> " . number_format($items_per_order_this_month, 2) . " (" . number_format($items_per_order_last_month, 2) . ") " . display_change($items_per_order_this_month, $items_per_order_last_month) . "</p>
            <p class='small-text'>Same Period Last Year: " . number_format($items_per_order_last_year_same_month, 2) . " " . display_change($items_per_order_this_month, $items_per_order_last_year_same_month) . "</p>
        </div>
    </div>";

    // Yearly comparison
    echo "<div class='order-stats-section'>
        <div class='order-stats-header'>Year: " . date('Y') . " vs Last Year</div>
        <div class='order-stats-data'>
            <p><strong>Average Order Price:</strong> " . wc_price($avg_order_this_year) . " (" . wc_price($avg_order_last_year) . ") " . display_change($avg_order_this_year, $avg_order_last_year) . "</p>
            <p><strong>Order Count:</strong> " . $order_count_this_year . " (" . $order_count_last_year . ") " . display_change($order_count_this_year, $order_count_last_year) . "</p>
            <p><strong>Items per Order:</strong> " . number_format($items_per_order_this_year, 2) . " (" . number_format($items_per_order_last_year, 2) . ") " . display_change($items_per_order_this_year, $items_per_order_last_year) . "</p>
        </div>
    </div>";
}

// Functions to get orders for specific periods
function get_orders_today() {
    return wc_get_orders(array(
        'limit' => -1,
        'date_created' => date('Y-m-d'),
        'status' => 'completed',
    ));
}

function get_orders_for_day($day) {
    return wc_get_orders(array(
        'limit' => -1,
        'date_created' => $day,
        'status' => 'completed',
    ));
}

function get_orders_for_week($week_number, $year = null) {
    if (!$year) {
        $year = date('Y');
    }
    $start_date = new DateTime();
    $start_date->setISODate($year, $week_number);
    $end_date = clone $start_date;
    $end_date->modify('+6 days');

    return wc_get_orders(array(
        'limit' => -1,
        'date_created' => $start_date->format('Y-m-d') . '...' . $end_date->format('Y-m-d'),
        'status' => 'completed',
    ));
}

function get_orders_for_month($month, $year = null) {
    if (!$year) {
        $year = date('Y');
    }
    return wc_get_orders(array(
        'limit' => -1,
        'date_created' => $year . '-' . $month . '-01...' . $year . '-' . $month . '-31',
        'status' => 'completed',
    ));
}

function get_orders_for_year($year) {
    return wc_get_orders(array(
        'limit' => -1,
        'date_created' => $year . '-01-01...' . $year . '-12-31',
        'status' => 'completed',
    ));
}

function calculate_avg_order($orders) {
    if (empty($orders)) {
        return 0;
    }

    $total = 0;
    foreach ($orders as $order) {
        $total += $order->get_total();
    }

    return $total / count($orders);
}

function calculate_items_per_order($orders) {
    if (empty($orders)) {
        return 0;
    }

    $total_items = 0;
    foreach ($orders as $order) {
        $total_items += $order->get_item_count();
    }

    return $total_items / count($orders);
}
?>